/* 
 * Mirai. Copyright (C) 2024 Vyn
 * This file is licensed under version 3 of the GNU General Public License (GPL-3.0-only)
 * The license can be found in the LICENSE file or at https://www.gnu.org/licenses/gpl-3.0.txt
 */

import QtQuick
import QtQuick.Window
import QtQuick.Controls
import QtQuick.Layouts
import Mirai

Window {
	id: root
    width: 640
    height: 480
    visible: true
    title: qsTr("Hello World")

	

	property string selectedView: "list"

	Backend {
		id: backend
	}

	Item {
		id: colorPalette
		property QtObject selected: MiraiColorPalette
	}

	function capitalize(str) {
		return str.charAt(0).toUpperCase() + str.slice(1)
	}

	function openSettings() {
		filesForm.reset()
		filesFormPopup.open()
	}

	function newTask() {
		taskForm.taskToEdit = undefined
		taskForm.taskToEditIndex = -1
		taskFormPopup.open()
	}

	function editTask(task, taskIndex) {
		taskForm.taskToEdit = task
		taskForm.taskToEditIndex = taskIndex
		taskFormPopup.open()
	}

	Component {
		id: sideMenuComponent
		SideMenu {
			id: sideMenu
			
		}
	}
	
	Component {
		id: mainPanelComponent
		MainPanel {
		}
	}

	RowLayout {
		id: desktopLayout
        anchors.fill: parent
        spacing: 0

		Loader {
			sourceComponent: sideMenuComponent
			Layout.preferredWidth: item.width
			Layout.fillHeight: true
		}
		Loader {
			sourceComponent: mainPanelComponent
			Layout.fillWidth: true
			Layout.fillHeight: true
		}
        
    }

	SwipeView {
		id: phoneLayout
        anchors.fill: parent
        spacing: 0

		Loader {
			sourceComponent: sideMenuComponent
			Layout.preferredWidth: item.width
			Layout.fillHeight: true
		}
		Loader {
			sourceComponent: mainPanelComponent
			Layout.fillWidth: true
			Layout.fillHeight: true
		}
    }

	function setFittingLayout() {
		if (width > height) {
			desktopLayout.visible = true
			phoneLayout.visible = false
		} else {
			desktopLayout.visible = false
			phoneLayout.visible = true
			phoneLayout.setCurrentIndex(1)
		}
	}
	onWidthChanged: setFittingLayout()
	Component.onCompleted: setFittingLayout()
}
